<?php

namespace Drupal\layout_builder_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Block used to add a simple formatted text into a Layout Builder component.
 *
 * @Block(
 *   id = "layout_builder_block",
 *   admin_label = @Translation("Layout Builder Block"),
 * )
 */
class LayoutBuilderBlockBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Constructs a new block plugin instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AccountInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'text' => '',
      'format' => filter_default_format($this->currentUser),
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    // Override the parent to avoid showing the admin_label on new blocks.
    if (!empty($this->configuration['label'])) {
      return $this->configuration['label'];
    }
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    parent::blockSubmit($form, $form_state);
    $this->setConfigurationValue('text', $form_state->getValue(['content', 'value']));
    $this->setConfigurationValue('format', $form_state->getValue(['content', 'format']));
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form = parent::blockForm($form, $form_state);

    $form['content'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Content'),
      '#format' => $this->getConfiguration()['format'],
      '#default_value' => $this->getConfiguration()['text'],
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#type' => 'processed_text',
      '#text' => $this->getConfiguration()['text'],
      '#format' => $this->getConfiguration()['format'],
    ];
  }

}
